@@ -421,7 +421,7 @@ class LinearConfidence(Confidence):
             # Logging update on q-values
             LOGGER.info(
                 "\t- Found %i %s with q<=%g",
-                (data["mokapot q-value"] <= self._eval_fdr).sum(),
+                (data.loc[targets, "mokapot q-value"] <= self._eval_fdr).sum(),
                 level,
                 self._eval_fdr,
             )
